@@ -105,7 +105,11 @@ def create_fpga_strategy_selector() -> Callable[[str], Dict[str, Any]]:
         return {
             "pcie_ip_type": "pcie_7x",
             "family": fam,
-            "max_lanes": 8,
+            # 7-series lane support varies by family/package:
+            # - Artix-7: up to x4
+            # - Kintex-7: up to x8 (device/package dependent)
+            # Default conservatively for Artix-7 to x4 to avoid invalid IP settings.
+            "max_lanes": 8 if fam == "kintex7" else 4,
             "supports_msi": True,
             "supports_msix": True,
             "clock_constraints": f"{fam}.xdc",
@@ -142,7 +146,8 @@ def create_fpga_strategy_selector() -> Callable[[str], Dict[str, Any]]:
             ),
             prefix="BUILD",
         )
-        return artix75_or_kintex(fpga_part)  # sensible generic
+        # Generic 7-series default: treat as Artix-7 constraints (x4 max)
+        return artix75_or_kintex(fpga_part)
 
     return select
 
