@@ -12,13 +12,8 @@ from typing import Optional, Tuple, Union
 
 from src.device_clone.constants import BAR_SIZE_CONSTANTS
 from src.exceptions import ContextError
-from src.string_utils import (
-    log_debug_safe,
-    log_error_safe,
-    log_info_safe,
-    log_warning_safe,
-    safe_format,
-)
+from src.string_utils import (log_debug_safe, log_error_safe, log_info_safe,
+                              log_warning_safe, safe_format)
 
 logger = logging.getLogger(__name__)
 
