@@ -6,26 +6,18 @@ Provides functionality to build, load, and manage the donor_dump kernel module
 for extracting PCI device parameters.
 """
 
-import json
 import json
 import logging
 import os
 import random
 import subprocess
 import sys
-
 from pathlib import Path
 from typing import Any, Dict, Optional, Tuple
 
-
 # Project-standard logging utilities
-from src.string_utils import (
-    safe_format,
-    log_info_safe,
-    log_warning_safe,
-    log_error_safe,
-    log_debug_safe,
-)
+from src.string_utils import (log_debug_safe, log_error_safe, log_info_safe,
+                              log_warning_safe, safe_format)
 
 logger = logging.getLogger(__name__)
 LOG_PREFIX = "DONOR_DUMP"
@@ -823,7 +815,8 @@ class DonorDumpManager:
         )
 
         # Import vendor ID constants
-        from src.device_clone.constants import VENDOR_ID_INTEL, get_fallback_vendor_id
+        from src.device_clone.constants import (VENDOR_ID_INTEL,
+                                                get_fallback_vendor_id)
 
         # Convert to hex string format
         intel_vid_str = f"0x{VENDOR_ID_INTEL:04x}"
@@ -1024,7 +1017,8 @@ class DonorDumpManager:
                 # Optional standardized header (off by default for test parity)
                 if include_header:
                     try:
-                        from src.string_utils import generate_hex_header_comment
+                        from src.string_utils import \
+                            generate_hex_header_comment
 
                         header = generate_hex_header_comment(
                             title=(
