@@ -18,14 +18,8 @@ from pathlib import Path
 from typing import List, Optional
 
 from ..log_config import get_logger
-from ..string_utils import (
-    log_debug_safe,
-    log_error_safe,
-    log_info_safe,
-    log_warning_safe,
-    safe_format,
-    utc_timestamp,
-)
+from ..string_utils import (log_debug_safe, log_error_safe, log_info_safe,
+                            log_warning_safe, safe_format, utc_timestamp)
 
 ###############################################################################
 # Configuration constants - override with environment vars if desired.
