@@ -12,12 +12,8 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional, Set
 
 from ..log_config import get_logger
-from ..string_utils import (
-    log_debug_safe,
-    log_error_safe,
-    log_info_safe,
-    log_warning_safe,
-)
+from ..string_utils import (log_debug_safe, log_error_safe, log_info_safe,
+                            log_warning_safe)
 from .repo_manager import RepoManager
 
 logger = get_logger(__name__)
@@ -317,6 +313,11 @@ class TemplateDiscovery:
             "pcileech_com.sv",
             "pcileech_pcie_cfg_a7.sv",
             "pcileech_pcie_cfg_us.sv",
+            "pcileech.svh",
+            "tlp_pkg.svh",  # TLP package definitions
+            "bar_controller.sv",
+            "cfg_shadow.sv",
+            "pcileech_pcie_tlp_a7.sv",
         ]
 
         # Search in common locations
