@@ -43,21 +43,15 @@ import sys
 from typing import Any, Dict, List, Optional, Set, Tuple
 
 try:
-    from scripts.kernel_utils import (
-        check_linux_requirement,
-        ensure_kernel_source,
-        find_driver_sources,
-        resolve_driver_module,
-    )
+    from scripts.kernel_utils import (check_linux_requirement,
+                                      ensure_kernel_source,
+                                      find_driver_sources,
+                                      resolve_driver_module)
     from scripts.state_machine_extractor import StateMachineExtractor
 except ImportError:
     # Fallback for when running as script directly
-    from kernel_utils import (
-        check_linux_requirement,
-        ensure_kernel_source,
-        find_driver_sources,
-        resolve_driver_module,
-    )
+    from kernel_utils import (check_linux_requirement, ensure_kernel_source,
+                              find_driver_sources, resolve_driver_module)
     from state_machine_extractor import StateMachineExtractor
 
 # Module-level regex patterns for register analysis
