@@ -20,7 +20,7 @@ from ..device_clone.manufacturing_variance import DeviceClass
 # Import from centralized utils
 from ..string_utils import generate_sv_header_comment
 from ..utils.unified_context import TemplateObject
-from ..utils.validation_constants import POWER_TRANSITION_CYCLES
+from ..utils.validation_constants import get_power_transition_cycles
 
 # Import template renderer
 from . import TemplateRenderer, TemplateRenderError
@@ -29,6 +29,10 @@ from . import TemplateRenderer, TemplateRenderError
 from .advanced_sv_features import LinkState, PowerState
 
 
+_DEFAULT_TRANSITION_CYCLES = get_power_transition_cycles()
+_TRANSITION_KEYS = tuple(_DEFAULT_TRANSITION_CYCLES.keys())
+
+
 class ErrorType(Enum):
     """PCIe error types."""
 
@@ -47,7 +51,7 @@ class DeviceType(Enum):
     AUDIO_CONTROLLER = "audio"
 
 
-@dataclass
+@dataclass(slots=True)
 class PowerManagementConfig:
     """Configuration for power management features."""
 
@@ -60,10 +64,18 @@ class PowerManagementConfig:
     )
 
     # Power transition timing (in clock cycles)
-    d0_to_d1_cycles: int = POWER_TRANSITION_CYCLES.get("d0_to_d1", 100)
-    d1_to_d0_cycles: int = POWER_TRANSITION_CYCLES.get("d1_to_d0", 200)
-    d0_to_d3_cycles: int = POWER_TRANSITION_CYCLES.get("d0_to_d3", 500)
-    d3_to_d0_cycles: int = POWER_TRANSITION_CYCLES.get("d3_to_d0", 1000)
+    d0_to_d1_cycles: int = field(
+        default_factory=lambda: _DEFAULT_TRANSITION_CYCLES["d0_to_d1"]
+    )
+    d1_to_d0_cycles: int = field(
+        default_factory=lambda: _DEFAULT_TRANSITION_CYCLES["d1_to_d0"]
+    )
+    d0_to_d3_cycles: int = field(
+        default_factory=lambda: _DEFAULT_TRANSITION_CYCLES["d0_to_d3"]
+    )
+    d3_to_d0_cycles: int = field(
+        default_factory=lambda: _DEFAULT_TRANSITION_CYCLES["d3_to_d0"]
+    )
 
     # Link state transition timing
     l0_to_l0s_cycles: int = 10
@@ -77,7 +89,7 @@ class PowerManagementConfig:
     enable_dynamic_voltage_scaling: bool = False
 
 
-@dataclass
+@dataclass(slots=True)
 class PerformanceConfig:
     """Configuration for performance monitoring features."""
 
@@ -94,7 +106,7 @@ class PerformanceConfig:
     enable_threshold_alerts: bool = False
 
 
-@dataclass
+@dataclass(slots=True)
 class ErrorHandlingConfig:
     """Configuration for error handling features."""
 
@@ -211,9 +223,7 @@ class SystemVerilogGenerator:
             raise TemplateRenderError(f"Missing required template fields: {missing}")
 
         # Render main module template
-        return self.renderer.render_template(
-            "systemverilog/advanced/main_module.sv.j2", context
-        )
+        return self.renderer.render_template("sv/main_module.sv.j2", context)
 
     def _build_device_config_context(self) -> TemplateObject:
         """Build device config context for templates, with all required fields."""
@@ -238,19 +248,21 @@ class SystemVerilogGenerator:
 
     def _build_power_context(self) -> TemplateObject:
         """Build power management context for templates."""
+        transition_cycles = {
+            key: getattr(
+                self.power_config,
+                f"{key}_cycles",
+                _DEFAULT_TRANSITION_CYCLES[key],
+            )
+            for key in _TRANSITION_KEYS
+        }
+
         return TemplateObject(
             {
                 "supported_states": [
                     state.value for state in self.power_config.supported_power_states
                 ],
-                "transition_cycles": TemplateObject(
-                    {
-                        "d0_to_d1": self.power_config.d0_to_d1_cycles,
-                        "d1_to_d0": self.power_config.d1_to_d0_cycles,
-                        "d0_to_d3": self.power_config.d0_to_d3_cycles,
-                        "d3_to_d0": self.power_config.d3_to_d0_cycles,
-                    }
-                ),
+                "transition_cycles": TemplateObject(transition_cycles),
                 "enable_clock_gating": self.power_config.enable_clock_gating,
                 "enable_power_gating": self.power_config.enable_power_gating,
             }
@@ -310,9 +322,7 @@ class SystemVerilogGenerator:
         }
 
         # Render template using the existing TemplateRenderer
-        return self.renderer.render_template(
-            "systemverilog/advanced/clock_crossing.sv.j2", context
-        )
+        return self.renderer.render_template("sv/clock_crossing.sv.j2", context)
 
 
 # Alias for backward compatibility
