@@ -101,6 +101,7 @@ class TemplateRenderer:
         sandboxed: bool = False,
         bytecode_cache_dir: Optional[Union[str, Path]] = None,
         auto_reload: bool = True,
+        prefix: str = "TEMPL",
     ):
         """
         Initialize the template renderer.
@@ -117,6 +118,7 @@ class TemplateRenderer:
         template_dir = Path(template_dir or Path(__file__).parent.parent / "templates")
         template_dir.mkdir(parents=True, exist_ok=True)
         self.template_dir = template_dir
+        self.prefix = prefix
 
         # Choose undefined class based on strict mode
         undefined_cls = StrictUndefined if strict else Undefined
@@ -155,7 +157,7 @@ class TemplateRenderer:
                 "Template renderer initialized with directory: {template_dir}",
                 template_dir=self.template_dir,
             ),
-            prefix="TEMPLATE",
+            prefix=prefix,
         )
 
     def _setup_custom_filters(self):
@@ -466,7 +468,7 @@ class TemplateRenderer:
                     log_debug_safe(
                         logger,
                         "Template constants not available",
-                        prefix="TEMPLATE",
+                        prefix=self.prefix,
                     )
 
             except Exception as e:
@@ -477,7 +479,7 @@ class TemplateRenderer:
                         "ensure_template_compatibility failed, using original context: {error}",
                         error=e,
                     ),
-                    prefix="TEMPLATE",
+                    prefix=self.prefix,
                 )
                 compatible = context
 
@@ -500,7 +502,7 @@ class TemplateRenderer:
                         "TemplateContextValidator unavailable or failed: {error}",
                         error=e,
                     ),
-                    prefix="TEMPLATE",
+                    prefix=self.prefix,
                 )
 
             # Render the template with the validated/compatible context
@@ -520,7 +522,7 @@ class TemplateRenderer:
                 template_name=template_name,
                 error=e,
             )
-            log_error_safe(logger, error_msg, prefix="TEMPLATE")
+            log_error_safe(logger, error_msg, prefix=self.prefix)
             raise TemplateRenderError(error_msg) from e
 
     def render_string(self, template_string: str, context: Dict[str, Any]) -> str:
@@ -710,7 +712,7 @@ class TemplateRenderer:
                         "TemplateContextValidator failed, falling back to basic preparation: {error}",
                         error=e,
                     ),
-                    prefix="TEMPLATE",
+                    prefix=self.prefix,
                 )
                 validated_context = context.copy()
 
@@ -729,7 +731,7 @@ class TemplateRenderer:
                                 "Failed to convert timing_config dataclass: {error}",
                                 error=e,
                             ),
-                            prefix="TEMPLATE",
+                            prefix=self.prefix,
                         )
 
             return validated_context
@@ -743,7 +745,7 @@ class TemplateRenderer:
                     name=(template_name or "unknown"),
                     error=e,
                 ),
-                prefix="TEMPLATE",
+                prefix=self.prefix,
             )
             return context.copy()
 
@@ -766,7 +768,7 @@ class TemplateRenderer:
         log_debug_safe(
             logger,
             "Cleared template renderer caches",
-            prefix="TEMPLATE",
+            prefix=self.prefix,
         )
 
 
