@@ -1565,7 +1565,9 @@ def test_firmware_builder_generate_tcl_scripts(mock_firmware_builder):
                 "vendor_id": "0x1234",
                 "subsystem_vendor_id": "0x1234",
                 "subsystem_device_id": "0x5678",
-            }
+            },
+            "pcie_max_link_speed": 2,  # Gen2 - 5.0 GT/s
+            "pcie_max_link_width": 4,  # x4 lanes
         }
     }
 
@@ -1581,6 +1583,8 @@ def test_firmware_builder_generate_tcl_scripts(mock_firmware_builder):
         subsys_device_id=0x5678,  # Converted to int by _optional_int
         build_jobs=builder.config.vivado_jobs,
         build_timeout=builder.config.vivado_timeout,
+        pcie_max_link_speed_code=2,  # Extracted from template context
+        pcie_max_link_width=4,  # Extracted from template context
     )
 
 
