@@ -10,9 +10,7 @@ from unittest.mock import MagicMock, call, patch
 sys.path.insert(0, str(Path(__file__).parent.parent))
 
 from src.vivado_handling.pcileech_build_integration import (
-    PCILeechBuildIntegration,
-    integrate_pcileech_build,
-)
+    PCILeechBuildIntegration, integrate_pcileech_build)
 
 
 class TestPCILeechBuildIntegration(unittest.TestCase):
